@@ -17,6 +17,7 @@
 package e2e
 
 import (
+	"fmt"
 	"strings"
 	"testing"
 	"time"
@@ -55,18 +56,21 @@ func TestTektonPipeline(t *testing.T) {
 	_, err = kubectl.Run("apply", "-f", basedir+"/kn-deployer-rbac.yaml")
 	assert.NilError(t, err)
 
-	_, err = kubectl.Run("apply", "-f", "https://raw.githubusercontent.com/tektoncd/catalog/master/buildah/buildah.yaml")
+	_, err = kubectl.Run("apply", "-f", tektonCatalogTask("git-clone", "0.1"))
 	assert.NilError(t, err)
 
-	_, err = kubectl.Run("apply", "-f", "https://raw.githubusercontent.com/tektoncd/catalog/master/kn/kn.yaml")
+	_, err = kubectl.Run("apply", "-f", basedir+"/resources.yaml")
+	assert.NilError(t, err)
+
+	_, err = kubectl.Run("apply", "-f", tektonCatalogTask("buildah", "0.1"))
+	assert.NilError(t, err)
+
+	_, err = kubectl.Run("apply", "-f", tektonCatalogTask("kn", "0.1"))
 	assert.NilError(t, err)
 
 	_, err = kubectl.Run("apply", "-f", basedir+"/kn-pipeline.yaml")
 	assert.NilError(t, err)
 
-	_, err = kubectl.Run("apply", "-f", basedir+"/kn-pipeline-resource.yaml")
-	assert.NilError(t, err)
-
 	_, err = kubectl.Run("create", "-f", basedir+"/kn-pipeline-run.yaml")
 	assert.NilError(t, err)
 
@@ -88,3 +92,11 @@ func waitForPipelineSuccess(k test.Kubectl) error {
 		return strings.Contains(out, "True"), err
 	})
 }
+
+func tektonCatalogTask(taskName, version string) string {
+	return fmt.Sprintf(
+		"https://raw.githubusercontent.com/tektoncd/catalog/"+
+			"master/task/%s/%s/%s.yaml",
+		taskName, version, taskName,
+	)
+}
